@@ -1,5 +1,9 @@
+"""
+.. include:: ./example.md
+"""
+# __all__ = ["cgdb", "resources"]
 from cgdb.cgdb import CGDB
 from cgdb import exceptions
-from cgdb import recources
+from cgdb import resources
 from cgdb import managers
 from cgdb import utils
