@@ -276,5 +276,7 @@ class DataSetsManager(ManagerMix):
                    "dataSetType": data_set_type,
                    "description": description}
 
-        test = self.post(url, json.dumps(content))
-        print(test)
\ No newline at end of file
+        self.post(url, json.dumps(content))
+
+    def delete_data_set(self, data_set: DataSets):
+        self.delete(data_set.url)
