@@ -1,3 +1,5 @@
+import json
+
 from cgdb.resources.level import Level
 from cgdb.utils.ManagerMix import ManagerMix
 
@@ -24,3 +26,12 @@ class LevelsManager(ManagerMix):
         content = self.get("levels/" + str(code))
 
         return Level(**content)
+
+    def create_level(self, code, description, level):
+        out = {"code": code,
+                "level": level,
+                "description": description}
+        result = self.post("levels", json.dumps(out))
+        if result.status_code != 200 and result.status_code != 204:
+            raise Exception("upload fail on server side\n Server error:"+result.content.decode("ASCII"))
+
